@@ -40,7 +40,7 @@ class HomeControl(Mprm):
     :param zeroconf_instance: Zeroconf instance to be potentially reused
     """
 
-    def __init__(self, gateway_id: str, mydevolo_instance: Mydevolo, zeroconf_instance: Optional[Zeroconf] = None):
+    def __init__(self, gateway_id: str, mydevolo_instance: Mydevolo, zeroconf_instance: Optional[Zeroconf] = None) -> None:
         self._mydevolo = mydevolo_instance
         self._session = requests.Session()
         self._session.headers.update({"User-Agent": f"devolo_home_control_api/{__version__}"})
@@ -130,7 +130,7 @@ class HomeControl(Mprm):
         self.updater.devices = self.devices
         return (devices[0], mode)
 
-    def on_update(self, message: Dict[str, Any]):
+    def on_update(self, message: Dict[str, Any]) -> None:
         """
         Initialize steps needed to update properties on a new message.
 
@@ -138,7 +138,7 @@ class HomeControl(Mprm):
         """
         self.updater.update(message)
 
-    def _binary_sensor(self, uid_info: Dict[str, Any]):
+    def _binary_sensor(self, uid_info: Dict[str, Any]) -> None:
         """Process BinarySensor properties"""
         device_uid = get_device_uid_from_element_uid(uid_info["UID"])
         if not hasattr(self.devices[device_uid], "binary_sensor_property"):
@@ -151,7 +151,7 @@ class HomeControl(Mprm):
             sub_type=uid_info["properties"]["subType"],
         )
 
-    def _binary_switch(self, uid_info: Dict[str, Any]):
+    def _binary_switch(self, uid_info: Dict[str, Any]) -> None:
         """Process BinarySwitch properties."""
         device_uid = get_device_uid_from_element_uid(uid_info["UID"])
         if not hasattr(self.devices[device_uid], "binary_switch_property"):
@@ -164,7 +164,7 @@ class HomeControl(Mprm):
             enabled=uid_info["properties"]["guiEnabled"],
         )
 
-    def _general_device(self, uid_info: Dict[str, Any]):
+    def _general_device(self, uid_info: Dict[str, Any]) -> None:
         """Process general device setting (gds) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding general device settings to %s.", device_uid)
@@ -178,11 +178,11 @@ class HomeControl(Mprm):
             zones=self.gateway.zones,
         )
 
-    def _grouping(self):
+    def _grouping(self) -> None:
         """Get all zones (also called rooms)."""
         self.gateway.zones = self.get_all_zones()
 
-    def _humidity_bar(self, uid_info: Dict[str, Any]):
+    def _humidity_bar(self, uid_info: Dict[str, Any]) -> None:
         """
         Process HumidityBarZone and HumidityBarValue properties.
 
@@ -204,7 +204,7 @@ class HomeControl(Mprm):
             self._logger.debug("Adding humidity bar position property to %s.", device_uid)
             self.devices[device_uid].humidity_bar_property[fake_element_uid].value = uid_info["properties"]["value"]
 
-    def _inspect_devices(self, devices: List[str]):
+    def _inspect_devices(self, devices: List[str]) -> None:
         """Inspect device properties of given list of devices."""
         devices_properties = self.get_data_from_uid_list(devices)
         for device_properties in devices_properties:
@@ -236,13 +236,11 @@ class HomeControl(Mprm):
             uid.pending_operations = uid.pending_operations or bool(uid_info["properties"].get("pendingOperations"))
 
         # Last activity messages sometimes arrive before a device was initialized and therefore need to be handled afterwards.
-        [  # pylint: disable=expression-not-assigned
-            self._last_activity(uid_info)
-            for uid_info in device_properties_list
-            if uid_info["UID"].startswith("devolo.LastActivity")
-        ]
+        for uid_info in device_properties_list:
+            if uid_info["UID"].startswith("devolo.LastActivity"):
+                self._last_activity(uid_info)
 
-    def _automatic_calibration(self, uid_info: Dict[str, Any]):
+    def _automatic_calibration(self, uid_info: Dict[str, Any]) -> None:
         """Process automatic calibration (acs) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding automatic calibration setting to %s.", device_uid)
@@ -252,7 +250,7 @@ class HomeControl(Mprm):
             calibration_status=bool(uid_info["properties"]["calibrationStatus"]),
         )
 
-    def _binary_sync(self, uid_info: Dict[str, Any]):
+    def _binary_sync(self, uid_info: Dict[str, Any]) -> None:
         """
         Process binary sync setting (bss) properties. Currently only the direction of a shutter in known to be a binary sync
         setting property, so it is named nicely.
@@ -263,7 +261,7 @@ class HomeControl(Mprm):
             element_uid=uid_info["UID"], setter=self.set_setting, inverted=uid_info["properties"]["value"]
         )
 
-    def _binary_async(self, uid_info: Dict[str, Any]):
+    def _binary_async(self, uid_info: Dict[str, Any]) -> None:
         """Process binary async setting (bas) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding binary async settings to %s.", device_uid)
@@ -279,7 +277,7 @@ class HomeControl(Mprm):
             key = camel_case_to_snake_case(uid_info["UID"].split("#")[-1])
             self.devices[device_uid].settings_property[key] = settings_property
 
-    def _last_activity(self, uid_info: Dict[str, Any]):
+    def _last_activity(self, uid_info: Dict[str, Any]) -> None:
         """
         Process last activity properties. Those don't go into an own property but will be appended to a parent property.
         This parent property is found by string replacement.
@@ -296,7 +294,7 @@ class HomeControl(Mprm):
                 "lastActivityTime"
             ]
 
-    def _led(self, uid_info: Dict[str, Any]):
+    def _led(self, uid_info: Dict[str, Any]) -> None:
         """Process LED information setting (lis) and visual feedback setting (vfs) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding led settings to %s.", device_uid)
@@ -308,7 +306,7 @@ class HomeControl(Mprm):
             element_uid=uid_info["UID"], setter=self.set_setting, led_setting=led_setting
         )
 
-    def _meter(self, uid_info: Dict[str, Any]):
+    def _meter(self, uid_info: Dict[str, Any]) -> None:
         """Process meter properties."""
         device_uid = get_device_uid_from_element_uid(uid_info["UID"])
         if not hasattr(self.devices[device_uid], "consumption_property"):
@@ -321,7 +319,7 @@ class HomeControl(Mprm):
             total_since=uid_info["properties"]["sinceTime"],
         )
 
-    def _multilevel_async(self, uid_info: Dict[str, Any]):
+    def _multilevel_async(self, uid_info: Dict[str, Any]) -> None:
         """Process multilevel async setting (mas) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         try:
@@ -338,7 +336,7 @@ class HomeControl(Mprm):
             element_uid=uid_info["UID"], setter=self.set_setting, value=uid_info["properties"]["value"]
         )
 
-    def _multilevel_sync(self, uid_info: Dict[str, Any]):
+    def _multilevel_sync(self, uid_info: Dict[str, Any]) -> None:
         """Process multilevel sync setting (mss) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
 
@@ -363,7 +361,7 @@ class HomeControl(Mprm):
                 element_uid=uid_info["UID"], setter=self.set_setting, motion_sensitivity=uid_info["properties"]["value"]
             )
 
-    def _multi_level_sensor(self, uid_info: Dict[str, Any]):
+    def _multi_level_sensor(self, uid_info: Dict[str, Any]) -> None:
         """Process multi level sensor properties."""
         device_uid = get_device_uid_from_element_uid(uid_info["UID"])
         if not hasattr(self.devices[device_uid], "multi_level_sensor_property"):
@@ -376,7 +374,7 @@ class HomeControl(Mprm):
             sensor_type=uid_info["properties"]["sensorType"],
         )
 
-    def _multi_level_switch(self, uid_info: Dict[str, Any]):
+    def _multi_level_switch(self, uid_info: Dict[str, Any]) -> None:
         """Process multi level switch properties."""
         device_uid = get_device_uid_from_element_uid(uid_info["UID"])
         if not hasattr(self.devices[device_uid], "multi_level_switch_property"):
@@ -391,7 +389,7 @@ class HomeControl(Mprm):
             min=uid_info["properties"]["min"],
         )
 
-    def _parameter(self, uid_info: Dict[str, Any]):
+    def _parameter(self, uid_info: Dict[str, Any]) -> None:
         """Process custom parameter setting (cps) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding parameter settings to %s.", device_uid)
@@ -399,7 +397,7 @@ class HomeControl(Mprm):
             element_uid=uid_info["UID"], setter=self.set_setting, param_changed=uid_info["properties"]["paramChanged"]
         )
 
-    def _protection(self, uid_info: Dict[str, Any]):
+    def _protection(self, uid_info: Dict[str, Any]) -> None:
         """Process protection setting (ps) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding protection settings to %s.", device_uid)
@@ -410,7 +408,7 @@ class HomeControl(Mprm):
             remote_switching=uid_info["properties"]["remoteSwitch"],
         )
 
-    def _remote_control(self, uid_info: Dict[str, Any]):
+    def _remote_control(self, uid_info: Dict[str, Any]) -> None:
         """Process remote control properties."""
         device_uid = get_device_uid_from_element_uid(uid_info["UID"])
         self._logger.debug("Adding remote control to %s.", device_uid)
@@ -424,7 +422,7 @@ class HomeControl(Mprm):
             type=uid_info["properties"]["type"],
         )
 
-    def _switch_type(self, uid_info: Dict[str, Any]):
+    def _switch_type(self, uid_info: Dict[str, Any]) -> None:
         """
         Process switch type setting (sts) properties. Interestingly, a switch with two buttons reports a switchType of 1 and a
         switch with four buttons reports a switchType of 2. This confusing behavior is corrected by doubling the value.
@@ -435,7 +433,7 @@ class HomeControl(Mprm):
             element_uid=uid_info["UID"], setter=self.set_setting, value=uid_info["properties"]["switchType"] * 2
         )
 
-    def _temperature_report(self, uid_info: Dict[str, Any]):
+    def _temperature_report(self, uid_info: Dict[str, Any]) -> None:
         """Process temperature report setting (trs) properties."""
         device_uid = get_device_uid_from_setting_uid(uid_info["UID"])
         self._logger.debug("Adding temperature report settings to %s.", device_uid)
@@ -446,7 +444,7 @@ class HomeControl(Mprm):
             target_temp_report=uid_info["properties"]["targetTempReport"],
         )
 
-    def _unknown(self, uid_info: Dict[str, Any]):
+    def _unknown(self, uid_info: Dict[str, Any]) -> None:
         """Ignore unknown properties."""
         ignore = ("devolo.SirenBinarySensor", "devolo.SirenMultiLevelSensor", "ss", "mcs")
         if not uid_info["UID"].startswith(ignore):
